@@ -45,7 +45,7 @@
     1 /* MIN is the fresh start op-version, mostly                             \
          should not change */
 #define GD_OP_VERSION_MAX                                                      \
-    GD_OP_VERSION_7_0 /* MAX VERSION is the maximum                            \
+    GD_OP_VERSION_10_0 /* MAX VERSION is the maximum                           \
                          count in VME table, should                            \
                          keep changing with                                    \
                          introduction of newer                                 \
@@ -116,6 +116,17 @@
 #define GD_OP_VERSION_6_0 60000 /* Op-version for GlusterFS 6.0 */
 
 #define GD_OP_VERSION_7_0 70000 /* Op-version for GlusterFS 7.0 */
+#define GD_OP_VERSION_7_1 70100 /* Op-version for GlusterFS 7.1 */
+#define GD_OP_VERSION_7_2 70200 /* Op-version for GlusterFS 7.2 */
+#define GD_OP_VERSION_7_3 70300 /* Op-version for GlusterFS 7.3 */
+
+#define GD_OP_VERSION_8_0 80000 /* Op-version for GlusterFS 8.0 */
+
+#define GD_OP_VERSION_9_0 90000 /* Op-version for GlusterFS 9.0 */
+
+#define GD_OP_VERSION_10_0 100000 /* Op-version for GlusterFS 10.0 */
+
+#define GD_OP_VERSION_11_0 110000 /* Op-version for GlusterFS 11.0 */
 
 #define GD_OP_VER_PERSISTENT_AFR_XATTRS GD_OP_VERSION_3_6_0
 
@@ -128,10 +139,6 @@
 
 xlator_t **
 __glusterfs_this_location(void);
-xlator_t *
-glusterfs_this_get(void);
-void
-glusterfs_this_set(xlator_t *);
 
 extern xlator_t global_xlator;
 extern struct volume_options global_xl_options[];
@@ -162,6 +169,9 @@ glusterfs_leaseid_exist(void);
 int
 glusterfs_globals_init(glusterfs_ctx_t *ctx);
 
+void
+gf_thread_needs_cleanup(void);
+
 struct tvec_base *
 glusterfs_ctx_tw_get(glusterfs_ctx_t *ctx);
 void
@@ -175,4 +185,6 @@ int
 gf_global_mem_acct_enable_get(void);
 int
 gf_global_mem_acct_enable_set(int val);
+
+extern glusterfs_ctx_t *global_ctx;
 #endif /* !_GLOBALS_H */
